@@ -115,7 +115,7 @@
 
 ##         stat_out[[ind]] <- f
 ##         ind <- ind + 1
-        
+
 ##     }
 
 ##     ## Close seats
@@ -139,7 +139,7 @@
 ##     ## Partisan Symmetry - simple
 ##     if("ps_simple" %in% stats){
 ##         cat("Calculating partisan symmetry by seats-votes inversion.\n")
-        
+
 ##         ## Set up swing
 ##         statebase <- sum(group1vote) /
 ##             (sum(group1vote) + sum(group2vote))
@@ -167,7 +167,7 @@
 
 ##         stat_out[[ind]] <- unlist(ps)
 ##         ind <- ind + 1
-        
+
 ##     }
 
 ##     ## Efficiency gap
@@ -186,7 +186,7 @@
 
 ##         stat_out[[ind]] <- unlist(egap)
 ##         ind <- ind + 1
-        
+
 ##     }
 
 ##     ## Partisan symmetry - full distribution
@@ -252,10 +252,10 @@
 
 ##     stats <- stats[match(c("ec", "mc", "ps_simple", "eg", "ps_full"), stats)]
 ##     stats <- stats[!is.na(stats)]
-    
+
 ##     names(stat_out) <- stats
 ##     return(stat_out)
-    
+
 ## }
 
 ## #' Polsby-Popper calculation for MCMC
@@ -267,7 +267,7 @@
 ##     if(min(unlist(adj_list)) == 1){
 ##         adj_list <- lapply(adj_list, function(x){x-1})
 ##     }
-##     partitions <- algout$partitions    
+##     partitions <- algout$partitions
 ##     cds_unique <- unique(partitions[,1])
 
 ##     store_pp <- matrix(NA, nsims, 3)
@@ -289,7 +289,7 @@
 ##     }
 
 ##     return(store_pp)
-    
+
 ## }
 
 ## #' Reock calculation for MCMC
@@ -319,181 +319,24 @@
 ##     }
 
 ##     return(store_reock)
-    
-## }
-
-## #' Diagnostic plotting functionality for MCMC redistricting.
-## #'
-## #' \code{redist.diagplot} generates several common MCMC diagnostic plots.
-## #'
-## #' @usage redist.diagplot(sumstat,
-## #' plot = c("trace", "autocorr", "densplot", "mean", "gelmanrubin"),
-## #' logit = FALSE, savename = NULL)
-## #'
-## #' @param sumstat A vector, list, \code{mcmc} or \code{mcmc.list} object
-## #' containing a summary statistic of choice.
-## #' @param plot The type of diagnostic plot to generate: one of "trace",
-## #' "autocorr", "densplot", "mean", "gelmanrubin". If \code{plot = "gelmanrubin"},
-## #' the input \code{sumstat} must be of class \code{mcmc.list} or \code{list}.
-## #' @param logit Flag for whether to apply the logistic transformation for the
-## #' summary statistic. The default is \code{FALSE}.
-## #' @param savename Filename to save the plot. Default is \code{NULL}.
-## #'
-## #' @details This function allows users to generate several standard diagnostic
-## #' plots from the MCMC literature, as implemented by Plummer et. al (2006).
-## #' Diagnostic plots implemented include trace plots, autocorrelation plots,
-## #' density plots, running means, and Gelman-Rubin convergence diagnostics
-## #' (Gelman & Rubin 1992).
-## #'
-## #' @return Returns a plot of file type \code{.pdf}.
-## #'
-## #' @references Fifield, Benjamin, Michael Higgins, Kosuke Imai and Alexander
-## #' Tarr. (2016) "A New Automated Redistricting Simulator Using Markov Chain Monte
-## #' Carlo." Working Paper. Available at
-## #' \url{http://imai.princeton.edu/research/files/redist.pdf}.
-## #'
-## #' Gelman, Andrew and Donald Rubin. (1992) "Inference from iterative simulations
-## #' using multiple sequences (with discussion)." Statistical Science.
-## #'
-## #' Plummer, Martin, Nicky Best, Kate Cowles and Karen Vines. (2006) "CODA:
-## #' Convergence Diagnosis and Output Analysis for MCMC." R News.
-## #'
-## #' @examples
-## #' \dontrun{
-## #' data(algdat.pfull)
-## #'
-## #' ## Get an initial partition
-## #' set.seed(1)
-## #' initcds <- algdat.pfull$cdmat[,sample(1:ncol(algdat.pfull$cdmat), 1)]
-## #'
-## #' ## 25 precinct, three districts - no pop constraint ##
-## #' alg_253 <- redist.mcmc(adjobj = algdat.pfull$adjlist,
-## #' popvec = algdat.pfull$precinct.data$pop,
-## #' initcds = initcds,nsims = 10000)
-## #'
-## #' ## Get Republican Dissimilarity Index from simulations
-## #' rep_dmi_253 <- redist.segcalc(alg_253,
-## #' algdat.pfull$precinct.data$repvote,
-## #' algdat.pfull$precinct.data$pop)
-## #'
-## #' ## Generate diagnostic plots
-## #' redist.diagplot(rep_dmi_253, plot = "trace")
-## #' redist.diagplot(rep_dmi_253, plot = "autocorr")
-## #' redist.diagplot(rep_dmi_253, plot = "densplot")
-## #' redist.diagplot(rep_dmi_253, plot = "mean")
-## #' }
-## #' @export
-## redist.diagplot <- function(sumstat,
-##                             plot = c("trace", "autocorr", "densplot",
-##                                 "mean", "gelmanrubin"),
-##                             logit = FALSE, savename = NULL
-##                             ){
-
-##     ##############
-##     ## Warnings ##
-##     ##############
-##     if(missing(sumstat)){
-##         stop("Please provide a vector or list of summary statistics to the function")
-##     }
-##     if(!(class(sumstat) %in% c("numeric", "list", "mcmc", "mcmc.list"))){
-##         stop("Please provide either a numeric vector, list, or mcmc object")
-##     }
-##     if(!(plot %in% c("trace", "autocorr", "densplot",
-##                      "mean", "gelmanrubin"))){
-##         stop("Sorry. We don't currently support that MCMC diagnostic.")
-##     }
-##     if(plot == "gelmanrubin" & !(class(sumstat) %in% c("list", "mcmc.list"))){
-##         stop("If generating a Gelman-Rubin plot, please provide an object of class list or mcmc.list")
-##     }
-    
-##     ########################
-##     ## Create mcmc object ##
-##     ########################
-##     if(class(sumstat) == "numeric"){
-##         segout <- mcmc(sumstat)
-##     }else if(class(sumstat) == "list"){
-##         for(i in 1:length(sumstat)){
-##             sumstat[[i]] <- mcmc(sumstat[[i]])
-##         }       
-##         segout <- mcmc.list(sumstat)
-##     }else if(class(sumstat) %in% c("mcmc", "mcmc.list")){
-##         segout <- sumstat
-##     }
-    
-##     ## Logit transform
-##     if(logit){
-##         if(class(segout) == "mcmc"){
-##             segout <- log(segout / (1 - segout))
-##         }else if(class(segout) == "mcmc.list"){
-##             for(i in 1:length(segout)){
-##                 segout[[i]] <- log(segout[[i]] / (1 - segout[[i]]))
-##             }
-##         }
-##     }
-
-##     ##################
-##     ## Create plots ##
-##     ##################
-##     if(plot == "trace"){
-##         if(!is.null(savename)){
-##             pdf(file = paste(savename, ".pdf", sep = ""))
-##         }
-##         traceplot(segout)
-##         if(!is.null(savename)){
-##             dev.off()
-##         }
-##     }
-##     if(plot == "autocorr"){
-##         if(!is.null(savename)){
-##             pdf(file = paste(savename, ".pdf", sep = ""))
-##         }
-##         autocorr.plot(segout, lag.max = 50)
-##         if(!is.null(savename)){
-##             dev.off()
-##         }
-##     }
-##     if(plot == "densplot"){
-##         if(!is.null(savename)){
-##             pdf(file = paste(savename, ".pdf", sep = ""))
-##         }
-##         densplot(segout)
-##         if(!is.null(savename)){
-##             dev.off()
-##         }
-##     }
-##     if(plot == "mean"){
-##         if(!is.null(savename)){
-##             pdf(file = paste(savename, ".pdf", sep = ""))
-##         }
-##         cumuplot(segout, probs = .5, type = "l", lty = 1)
-##         if(!is.null(savename)){
-##             dev.off()
-##         }
-##     }
-##     if(plot == "gelmanrubin" & class(segout) == "mcmc.list"){
-##         if(!is.null(savename)){
-##             pdf(file = paste(savename, ".pdf", sep = ""))
-##         }
-##         gelman.plot(segout, transform = FALSE)
-##         if(!is.null(savename)){
-##             dev.off()
-##         }
-##     }
 
 ## }
 
+
 #' Segregation index calculation for MCMC redistricting.
 #'
 #' \code{redist.segcalc} calculates the dissimilarity index of segregation (see
 #' Massey \& Denton 1987 for more details) for a specified subgroup under any
 #' redistricting plan.
 #'
-#' @usage redist.segcalc(algout, grouppop, fullpop)
-#'
-#' @param algout A matrix of congressional district assignments or a
+#' @param plans A matrix of congressional district assignments or a
 #' redist object.
-#' @param grouppop A vector of populations for some subgroup of interest.
-#' @param fullpop A vector containign the populations of each geographic unit.
+#' @param group_pop A vector of populations for some subgroup of interest.
+#' @param total_pop A vector containing the populations of each geographic unit.
+#' @param algout Deprecated. Use plans. A matrix of congressional district assignments or a
+#' redist object.
+#' @param grouppop Deprecated. Use group_pop. A vector of populations for some subgroup of interest.
+#' @param fullpop Deprecated. Use total_pop. A vector containing the populations of each geographic unit.
 #'
 #' @return \code{redist.segcalc} returns a vector where each entry is the
 #' dissimilarity index of segregation (Massey & Denton 1987) for each
@@ -509,61 +352,72 @@
 #'
 #' @examples
 #' \dontrun{
-#' data(algdat.pfull)
-#'
-#' ## Code to run the simulations in Figure 4 of Fifield, Higgins,
-#' ## Imai and Tarr (2015)
+#' data(fl25)
+#' data(fl25_enum)
+#' data(fl25_adj)
 #'
 #' ## Get an initial partition
-#' set.seed(1)
-#' initcds <- algdat.pfull$cdmat[,sample(1:ncol(algdat.pfull$cdmat), 1)]
+#' init_plan <- fl25_enum$plans[, 5118]
 #'
-#' ## Run simulations
-#' alg_253 <- redist.mcmc(adjobj = algdat.pfull$adjlist,
-#' popvec = algdat.pfull$precinct.data$pop,
-#' initcds = initcds, nsims = 10000)
+#' ## 25 precinct, three districts - no pop constraint ##
+#' alg_253 <- redist.mcmc(adj = fl25_adj, popvec = fl25$pop,
+#'                        initcds = init_plan, nsims = 10000)
 #'
 #' ## Get Republican Dissimilarity Index from simulations
-#' rep_dmi_253 <- redist.segcalc(alg_253,
-#' algdat.pfull$precinct.data$repvote,
-#' algdat.pfull$precinct.data$pop)
+#' rep_dmi_253 <- redist.segcalc(alg_253, fl25$mccain, fl25$pop)
 #' }
+#' @concept analyze
 #' @export
-redist.segcalc <- function(algout,
+redist.segcalc <- function(plans,
+                           group_pop,
+                           total_pop,
+                           algout,
                            grouppop,
-                           fullpop)
-{
+                           fullpop){
+
+    if(!missing(algout)){
+        plans <- algout
+        .Deprecated(new = 'plans', old = 'algout')
+    }
+    if(!missing(grouppop)){
+        group_pop <- grouppop
+        .Deprecated(new = 'group_pop', old = 'grouppop')
+    }
+    if(!missing(fullpop)){
+        total_pop <- fullpop
+        .Deprecated(new = 'total_pop', old = 'fullpop')
+    }
 
     ## Warnings
-    if(missing(algout) | !(class(algout) %in% c("data.frame", "matrix", "redist"))){
+    if(missing(plans) | !any(class(plans) %in% c("data.frame", "matrix", "redist"))){
         stop("Please provide either a redist object or a proper matrix of congessional districts")
     }
-    if(missing(grouppop)){
+    if(missing(group_pop)){
         stop("Please provide a vector of sub-group populations to calculate
 the segregation index")
     }
-    if(missing(fullpop)){
+    if(missing(total_pop)){
         stop("Please provide a vector of populations for each geographic unit")
     }
 
     ## If redist object, get the partitions entry
-    if(class(algout) == "redist"){
-        algout <- algout$partitions
+    if(all(class(plans) == 'redist')){
+        plans <- plans$plans
     }
-    
-    if(!((nrow(algout) == length(grouppop)) &
-             (length(grouppop) == length(fullpop)) &
-                 (length(fullpop) == nrow(algout)))){
+
+    if(!((nrow(plans) == length(group_pop)) &
+             (length(group_pop) == length(total_pop)) &
+                 (length(total_pop) == nrow(plans)))){
         stop("Please make sure there is a population entry for each geographic unit")
     }
 
     ## Calculate dissimilarity index
-    seg.out <- segregationcalc(algout,
-                               grouppop,
-                               fullpop)
+    seg.out <- segregationcalc(plans,
+                               group_pop,
+                               total_pop)
 
     ## Return
     return(seg.out)
-    
+
 }
-    
+
