@@ -7,7 +7,7 @@
 # parallel tempering (mpi)                   #
 ##############################################
 
-ecutsMPI <- function(procID = procID, params = params, adjobj = adjobj, popvec = popvec, initcds = initcds, swaps = swaps){
+ecutsMPI <- function(procID = procID, params = params, adj = adj, total_pop = total_pop, init_plan = init_plan, swaps = swaps){
     ## Load redist library
     library(redist)
 
@@ -16,12 +16,12 @@ ecutsMPI <- function(procID = procID, params = params, adjobj = adjobj, popvec =
     }else{
         fname <- paste0("log", procID, "_", params$savename)
     }
-    
+
     if(params$verbose){
         sink(fname)
         ## Initialize ##
         divider <- c(paste(rep("=", 20), sep = "", collapse = ""), "\n")
-        
+
         cat("\n", append = TRUE)
         cat(divider, append = TRUE)
         cat("redist.mcmc.mpi(): Automated Redistricting Simulation Using
@@ -29,11 +29,11 @@ ecutsMPI <- function(procID = procID, params = params, adjobj = adjobj, popvec =
     }
 
     ## Extract variables
-    if(is.na(grouppopvec)){
-        grouppopvec <- NULL
+    if(is.na(group_pop)){
+        group_pop <- NULL
     }
-    if(is.na(countymembership)){
-        countymembership <- NULL
+    if(is.na(counties)){
+        counties <- NULL
     }
     if(is.na(areasvec)){
         areasvec <- NULL
@@ -79,10 +79,10 @@ ecutsMPI <- function(procID = procID, params = params, adjobj = adjobj, popvec =
     }else{
         eprob <- params$eprob
     }
-    if(is.na(params$popcons)){
-        popcons <- NULL
+    if(is.na(params$pop_tol)){
+        pop_tol <- NULL
     }else{
-        popcons <- params$popcons
+        pop_tol <- params$pop_tol
     }
     if(is.na(params$lambda)){
         lambda <- NULL
@@ -119,8 +119,8 @@ ecutsMPI <- function(procID = procID, params = params, adjobj = adjobj, popvec =
     }else{
         savename <- params$savename
     }
-    if(sum(is.na(initcds)) == length(initcds)){
-        initcds <- NULL
+    if(sum(is.na(init_plan)) == length(init_plan)){
+        init_plan <- NULL
     }
     if(is.na(params$compactness_metric)){
         compactness_metric <- NULL
@@ -129,15 +129,15 @@ ecutsMPI <- function(procID = procID, params = params, adjobj = adjobj, popvec =
     }
 
     nthin <- params$nthin
-    
+
     ## Run redist preprocessing function
-    preprocout <- redist.preproc(adjobj = adjobj, popvec = popvec,
-                                 initcds = initcds, ndists = ndists,
-                                 popcons = popcons,
-                                 grouppopvec = grouppopvec,
+    preprocout <- redist.preproc(adj = adj, total_pop = total_pop,
+                                 init_plan = init_plan, ndists = ndists,
+                                 pop_tol = pop_tol,
+                                 group_pop = group_pop,
                                  areasvec = areasvec, #ctk-cran-note
                                  borderlength_mat = borderlength_mat,#ctk-cran-note
-                                 countymembership = countymembership,#ctk-cran-note
+                                 counties = counties,#ctk-cran-note
                                  ssdmat = ssdmat,
                                  compactness_metric = compactness_metric,#ctk-cran-note
                                  temper = FALSE,
@@ -150,27 +150,27 @@ ecutsMPI <- function(procID = procID, params = params, adjobj = adjobj, popvec =
 
     ## Set betas - if tempering, modified later
     beta <- params$beta
-    
+
     weightpop <- preprocout$params$weightpop
     weightcompact <- preprocout$params$weightcompact
-    weightseg <- preprocout$params$weightseg
+    weightvra <- preprocout$params$weightvra
     weightsimilar <- preprocout$params$weightsimilar
     weightcountysplit <- preprocout$params$weightcountysplit
     temper <- "parallel"
-    
+
     ## Find procID involved in swaps (non-adjacent only)
     if(!adjswaps){
         swapIts <- which(swaps == procID, arr.ind = TRUE)[,2]
     }
-    
+
     ## Set seed before first iteration of algorithm if provided by user
     if(!is.null(rngseed) & is.numeric(rngseed)){
         set.seed(rngseed)
     }
-    
+
     ## Get starting loop value
     loopstart <- loopscompleted + 1
-    
+
     for(i in loopstart:nloop){
 
         if(adjswaps){
@@ -187,56 +187,56 @@ ecutsMPI <- function(procID = procID, params = params, adjobj = adjobj, popvec =
 
         ## Get initial partition
         if(i > loopstart){
-            
+
             cds <- algout$partitions[,nsims]
-            
+
             if(temper == "parallel"){
                 beta <- algout$beta_sequence[nsims]
             }
-            
+
             if(!is.null(rngseed) & is.numeric(rngseed)){
                 .Random.seed <- algout$randseed
             }
 
             rm(list = "algout")
             algout <- list()
-                        
-        } else{ 
-            
+
+        } else{
+
             ## Reload the data if restarting
             if(loopstart > 1){
-                
+
                 ## Load the data
                 load(paste(savename,"_proc", procID, "_loop", i - 1, ".RData", sep = ""))
-                
+
                 ## Load the temperature adjacency matrix (need to specify WD)
                 load(paste0(savename,"_tempadjMat.RData"))
                 tempadj <- tempadjMat[nrow(tempadjMat),]
-                
+
                 ## Load the swapping schedule (need to specify WD)
                 load(paste0(savename,"_swaps.RData"))
-                
+
                 ## Stop if number of simulations per loop is different
                 if(nsims != ncol(algout[[1]])){
                     stop("Please specify the same number of simulations per
                loop across all loops")
                 }
-                
+
                 cds <- algout$partitions[,nsims]
-                
+
                 if(temper == "parallel"){
                     beta <- algout$beta_sequence[nsims]
                 }
-                
+
                 if(!is.null(rngseed) & is.numeric(rngseed)){
                     .Random.seed <- algout$randseed
                 }
 
                 rm(list = "algout")
                 algout <- list()
-                                
+
             }else{
-                cds <- preprocout$data$initcds
+                cds <- preprocout$data$init_plan
                 ## Initialize algout object (for use in ecutsAppend)
                 algout <- list()
                 ## Temperature Adjacency Matrix
@@ -244,9 +244,9 @@ ecutsMPI <- function(procID = procID, params = params, adjobj = adjobj, popvec =
                   tempadjMat <- tempadj
                 }
             }
-            
-        } 
-        
+
+        }
+
         #######################
         ## Run the algorithm ##
         #######################
@@ -258,11 +258,11 @@ ecutsMPI <- function(procID = procID, params = params, adjobj = adjobj, popvec =
             ## Run algorithm
             temp <- swMH(aList = preprocout$data$adjlist,
                          cdvec = cds,
-                         cdorigvec = preprocout$data$initcds,
-                         popvec = preprocout$data$popvec,
-                         grouppopvec = preprocout$data$grouppopvec,
+                         cdorigvec = preprocout$data$init_plan,
+                         popvec = preprocout$data$total_pop,
+                         grouppopvec = preprocout$data$group_pop,
                          areas_vec = preprocout$data$areasvec,
-                         county_membership = preprocout$data$countymembership,
+                         county_membership = preprocout$data$counties,
                          borderlength_mat = preprocout$data$borderlength_mat,
                          nsims = nsimsAdj[j],
                          eprob = eprob,
@@ -274,7 +274,7 @@ ecutsMPI <- function(procID = procID, params = params, adjobj = adjobj, popvec =
                          beta = beta,
                          weight_population = weightpop,
                          weight_compact = weightcompact,
-                         weight_segregation = weightseg,
+                         weight_vra = weightvra,
                          weight_similar = weightsimilar,
                          weight_countysplit = weightcountysplit,
                          adapt_beta = "none",
@@ -283,13 +283,13 @@ ecutsMPI <- function(procID = procID, params = params, adjobj = adjobj, popvec =
                          adapt_eprob = 0,
                          adapt_lambda = 0,
                          compactness_measure = compactness_metric)
-            
+
             ## Combine data
             algout <- ecutsAppend(algout,temp)
-            
+
             ## Get temperature
             beta <- temp$beta_sequence[nsimsAdj[j]]
-            
+
             ## Get likelihood
             like <- temp$energy_psi[nsimsAdj[j]]
             ## Use MPI to exchange swap information
@@ -302,9 +302,9 @@ ecutsMPI <- function(procID = procID, params = params, adjobj = adjobj, popvec =
             if(adjswaps){
 
                 ## Determine which nodes are swapping
-                tempseg <- swaps[(i-1)*nsims + j*freq]
+                tempvra <- swaps[(i-1)*nsims + j*freq]
                 ## Get node indices
-                temps <- tempadj[tempseg:(tempseg+1)]
+                temps <- tempadj[tempvra:(tempvra+1)]
                 ## Communication step
                 if(procID %in% temps){
                     ## Determine partner
@@ -315,7 +315,7 @@ ecutsMPI <- function(procID = procID, params = params, adjobj = adjobj, popvec =
                     ## Receive commands (blocking)
                     likePart <- Rmpi::mpi.recv.Robj(partner,tag=1)
                     betaPart <- Rmpi::mpi.recv.Robj(partner,tag=2)
-                    
+
                     ## Higher ranked process communicates random
                     ## draw to lower ranked process
                     if(partner < procID){
@@ -324,8 +324,8 @@ ecutsMPI <- function(procID = procID, params = params, adjobj = adjobj, popvec =
                     }else{
                         accept <- Rmpi::mpi.recv.Robj(partner,tag=3)
                     }
-                    
-                    ## Compute acceptance probability (for now, population only)                    
+
+                    ## Compute acceptance probability (for now, population only)
                     cat("Components of likelihood:\n", append = TRUE)
                     cat("like =", like, "\n", append = TRUE)
                     cat("beta =", beta, "\n", append = TRUE)
@@ -337,22 +337,22 @@ ecutsMPI <- function(procID = procID, params = params, adjobj = adjobj, popvec =
                     x_like <- -1 * beta * like
                     y_like <- -1 * betaPart * likePart
                     prob <- exp(a_like + b_like - x_like - y_like)
-                    
+
                     if(prob > accept){
                         ## Exchange temperature values
                         beta <- betaPart
-                        
+
                         ## Adjust temperature adjacency list
-                        tempadj[tempseg:(tempseg+1)] <- tempadj[(tempseg+1):tempseg]
+                        tempadj[tempvra:(tempvra+1)] <- tempadj[(tempvra+1):tempvra]
                         ## Send temperature adjacency list
-                        if(procID == tempadj[tempseg+1]){
+                        if(procID == tempadj[tempvra+1]){
                             oProcs <- tempadj[!(tempadj %in% temps)]
                             for(k in 1:length(oProcs)){
                                 Rmpi::mpi.send.Robj(tempadj,dest=oProcs[k],tag=4)
                             }
                         }
                     }else{
-                        if(procID == tempadj[tempseg]){
+                        if(procID == tempadj[tempvra]){
                             oProcs <- tempadj[!(tempadj %in% temps)]
                             for(k in 1:length(oProcs)){
                                 Rmpi::mpi.send.Robj(tempadj,dest=oProcs[k],tag=4)
@@ -360,7 +360,7 @@ ecutsMPI <- function(procID = procID, params = params, adjobj = adjobj, popvec =
                         }
                     }
                 }else{
-                    tempadj <- Rmpi::mpi.recv.Robj(tempadj[tempseg],tag=4)
+                    tempadj <- Rmpi::mpi.recv.Robj(tempadj[tempvra],tag=4)
                 }
             }else{
                 if(j != length(nsimsAdj) || length(nsimsAdj) == length(tempIts)){
@@ -371,7 +371,7 @@ ecutsMPI <- function(procID = procID, params = params, adjobj = adjobj, popvec =
                     ## Receive commands (blocking)
                     likePart <- Rmpi::mpi.recv.Robj(partner[j],tag=1)
                     betaPart <- Rmpi::mpi.recv.Robj(partner[j],tag=2)
-                    
+
                     ## Higher ranked process communicates random
                     ## draw to lower ranked process
                     if(partner[j] < procID){
@@ -381,7 +381,7 @@ ecutsMPI <- function(procID = procID, params = params, adjobj = adjobj, popvec =
                     else{
                         accept <- Rmpi::mpi.recv.Robj(partner[j],tag=3)
                     }
-                    
+
                     ## Compute acceptance probability
                     a_like <- -1 * betaPart * like
                     b_like <- -1 * beta * likePart
@@ -396,7 +396,7 @@ ecutsMPI <- function(procID = procID, params = params, adjobj = adjobj, popvec =
             }
             ## Update inputs to swMH
             cds <- temp$partitions[,nsimsAdj[j]]
-            
+
             ## Update tempadjMat
             if(adjswaps){
               ## Update temperature adjacency matrix
@@ -404,9 +404,9 @@ ecutsMPI <- function(procID = procID, params = params, adjobj = adjobj, popvec =
             }
             ## End loop over j
         }
-        
+
         class(algout) <- "redist"
-        
+
         ## Save random number state if setting the seed
         if(!is.null(rngseed)){
             algout$randseed <- .Random.seed
@@ -414,16 +414,16 @@ ecutsMPI <- function(procID = procID, params = params, adjobj = adjobj, popvec =
 
         ## Save output
         if(nloop > 1){
-            save(algout, file = paste(savename, "_proc", procID,"_loop", 
+            save(algout, file = paste(savename, "_proc", procID,"_loop",
                                       i, ".RData", sep = ""))
           ## Save temperature adjacency matrix
           if(adjswaps){
               save(tempadjMat, file = paste0(savename, "_tempadjMat.RData"))
           }
-          
+
           ## Save swaps
           save(swaps,file = paste0(savename, "_swaps.RData"))
-          
+
         }else if(!is.null(savename)){
             save(algout, file = paste(savename, "_chain",
                              algout$beta_sequence[nsims],
@@ -431,7 +431,7 @@ ecutsMPI <- function(procID = procID, params = params, adjobj = adjobj, popvec =
         }
         ## End loop over i
     }
-    
+
     ###############################
     ## Combine and save the data ##
     ###############################
@@ -445,11 +445,11 @@ ecutsMPI <- function(procID = procID, params = params, adjobj = adjobj, popvec =
             save(algout, file = paste(savename, ".RData", sep = ""))
         }
     }
-    
+
     if(params$verbose){
         cat("\n", append = TRUE)
         cat(divider, append = TRUE)
-        
+
         cat("redist.mcmc.mpi() simulations finished.\n", append = TRUE)
         sink()
     }
@@ -474,10 +474,10 @@ ecutsMPI <- function(procID = procID, params = params, adjobj = adjobj, popvec =
 #' \code{redist.mcmc.mpi} into a single \code{redist} object for analysis.
 #'
 #' @return \code{redist.combine.mpi} returns an object of class "redist".
-#' The object \code{redist} is a list that contains the folowing components (the
+#' The object \code{redist} is a list that contains the following components (the
 #' inclusion of some components is dependent on whether tempering
 #' techniques are used):
-#' \item{partitions}{Matrix of congressional district assignments generated by the
+#' \item{plans}{Matrix of congressional district assignments generated by the
 #' algorithm. Each row corresponds to a geographic unit, and each column
 #' corresponds to a simulation.}
 #' \item{distance_parity}{Vector containing the maximum distance from parity for
@@ -492,8 +492,8 @@ ecutsMPI <- function(procID = procID, params = params, adjobj = adjobj, popvec =
 #' constraint for each accepted redistricting plan.}
 #' \item{constraint_compact}{A vector containing the value of the compactness
 #' constraint for each accepted redistricting plan.}
-#' \item{constraint_segregation}{A vector containing the value of the
-#' segregation constraint for each accepted redistricting plan.}
+#' \item{constraint_vra}{A vector containing the value of the
+#' vra constraint for each accepted redistricting plan.}
 #' \item{constraint_similar}{A vector containing the value of the similarity
 #' constraint for each accepted redistricting plan.}
 #' \item{beta_sequence}{A vector containing the value of beta for each iteration
@@ -512,32 +512,32 @@ ecutsMPI <- function(procID = procID, params = params, adjobj = adjobj, popvec =
 #'
 #' @examples
 #' \dontrun{
-#' data(algdat.pfull)
+#' data(fl25)
+#' data(fl25_enum)
+#' data(fl25_adj)
 #'
 #' ## Code to run the simulations in Figure 4 in Fifield, Higgins, Imai and
 #' ## Tarr (2015)
 #'
 #' ## Get an initial partition
-#' set.seed(1)
-#' initcds <- algdat.pfull$cdmat[,sample(1:ncol(algdat.pfull$cdmat), 1)]
+#' init_plan <- fl25_enum$plans[, 5118]
 #'
 #' ## Run the algorithm
-#' redist.mcmc.mpi(adjobj = algdat.pfull$adjlist,
-#' popvec = algdat.pfull$precinct.data$pop,
-#' initcds = initcds,
-#' nsims = 10000, nloops = 2, savename = "test")
+#' redist.mcmc.mpi(adj = fl25_adj, total_pop = fl25$pop,
+#'                 init_plan = init_plan, nsims = 10000, nloops = 2, savename = "test")
 #' out <- redist.combine.mpi(savename = "test", nloop = 2,
-#' nthin = 10, tempadj = tempAdjMat)
+#'                           nthin = 10, tempadj = tempAdjMat)
 #' }
+#' @concept post
 #' @export
 redist.combine.mpi <- function(savename, nloop, nthin, tempadj){
-    
+
     ##############################
     ## Set up container objects ##
     ##############################
     load(paste(savename, "_proc", tempadj[1], "_loop1.RData", sep = ""))
     names_obj <- names(algout)
-    
+
     ## Create containers
     nr <- nrow(algout$partitions)
     nc <- ncol(algout$partitions)
@@ -547,10 +547,10 @@ redist.combine.mpi <- function(savename, nloop, nthin, tempadj){
     for(i in 1:length(veclist)){
         veclist[[i]] <- rep(NA, (nc * nloop / nthin))
     }
-    
+
     ## Indices for thinning
     indthin <- which((1:nc) %% nthin == 0)
-    
+
     ####################################
     ## Combine data in multiple loops ##
     ####################################
@@ -561,7 +561,7 @@ redist.combine.mpi <- function(savename, nloop, nthin, tempadj){
         load(paste(savename, "_proc", tempadj[1], "_loop", i, ".RData", sep = ""))
 
         ind <- ((i - 1) * (nc / nthin) + 1):(i * (nc / nthin))
-        
+
         ## Store objects together
         for(j in 1:length(algout)){
             if(j == 1){
@@ -570,9 +570,9 @@ redist.combine.mpi <- function(savename, nloop, nthin, tempadj){
                 veclist[[j-1]][ind] <- algout[[j]][indthin]
             }
         }
-        
+
     }
-    
+
     #################################
     ## Store data in algout object ##
     #################################
@@ -586,17 +586,17 @@ redist.combine.mpi <- function(savename, nloop, nthin, tempadj){
     }
     names(algout) <- names_obj
 
-    
+
     #########################
     ## Set class of object ##
     #########################
     class(algout) <- "redist"
-    
+
     #################
     ## Save object ##
     #################
     save(algout, file = paste(savename, ".RData", sep = ""))
-    
+
 }
 
 ecutsAppend <- function(algout,ndata){
@@ -621,27 +621,15 @@ ecutsAppend <- function(algout,ndata){
 #' \code{redist.mcmc.mpi} is used to simulate Congressional redistricting
 #' plans using Markov Chain Monte Carlo methods.
 #'
-#' @usage redist.mcmc.mpi(adjobj, popvec, nsims, ndists = NA, initcds = NULL,
-#' loopscompleted = 0, nloop = 1, nthin = 1,
-#' eprob = 0.05,
-#' lambda = 0, popcons = NA, grouppopvec = NA,
-#' areasvec = NA, countymembership = NA,
-#' borderlength_mat = NA, ssdmat = NA,
-#' compactness_metric = "fryer-holden", rngseed = NA,
-#' constraint = NA, constraintweights = NA,
-#' betaseq = "powerlaw",
-#' betaseqlength = 10, adjswaps = TRUE,
-#' freq = 100, savename = NA, maxiterrsg = 5000,
-#' contiguitymap = "rooks", verbose = FALSE)
 #'
-#' @param adjobj An adjacency matrix, list, or object of class
+#' @param adj An adjacency matrix, list, or object of class
 #' "SpatialPolygonsDataFrame."
-#' @param popvec A vector containing the populations of each geographic
+#' @param total_pop A vector containing the populations of each geographic
 #' unit.
 #' @param nsims The number of simulations run before a save point.
 #' @param ndists The number of congressional districts. The default is
 #' \code{NULL}.
-#' @param initcds A vector containing the congressional district labels
+#' @param init_plan A vector containing the congressional district labels
 #' of each geographic unit. The default is \code{NULL}. If not provided, random
 #' and contiguous congressional district assignments will be generated using
 #' \code{redist.rsg}.
@@ -657,15 +645,15 @@ ecutsAppend <- function(algout,ndata){
 #' @param lambda The parameter determining the number of swaps to attempt
 #' each iteration of the algorithm. The number of swaps each iteration is
 #' equal to Pois(\code{lambda}) + 1. The default is \code{0}.
-#' @param popcons The strength of the hard population
-#' constraint. \code{popcons} = 0.05 means that any proposed swap that
+#' @param pop_tol The strength of the hard population
+#' constraint. \code{pop_tol} = 0.05 means that any proposed swap that
 #' brings a district more than 5\% away from population parity will be
 #' rejected. The default is \code{NULL}.
-#' @param grouppopvec A vector of populations for some sub-group of
+#' @param group_pop A vector of populations for some sub-group of
 #' interest. The default is \code{NULL}.
 #' @param areasvec A vector of precinct areas for discrete Polsby-Popper.
 #' The default is \code{NULL}.
-#' @param countymembership A vector of county membership assignments. The default is \code{NULL}.
+#' @param counties A vector of county membership assignments. The default is \code{NULL}.
 #' @param borderlength_mat A matrix of border length distances, where
 #' the first two columns are the indices of precincts sharing a border and
 #' the third column is its distance. Default is \code{NULL}.
@@ -677,7 +665,7 @@ ecutsAppend <- function(algout,ndata){
 #' @param rngseed Allows the user to set the seed for the
 #' simulations. Default is \code{NULL}.
 #' @param constraint Which constraint to apply. Accepts any combination of \code{compact},
-#' \code{segregation}, \code{population}, \code{similarity}, or \code{none}
+#' \code{vra}, \code{population}, \code{similarity}, or \code{none}
 #' (no constraint applied). The default is NULL.
 #' @param constraintweights The weights to apply to each constraint. Should be a vector
 #' the same length as constraint. Default is NULL.
@@ -693,21 +681,37 @@ ecutsAppend <- function(algout,ndata){
 #' @param savename Filename to save simulations. Default is \code{NULL}.
 #' @param maxiterrsg Maximum number of iterations for random seed-and-grow
 #' algorithm to generate starting values. Default is 5000.
-#' @param contiguitymap Use queens or rooks distance criteria for generating an
-#' adjacency list from a "SpatialPolygonsDataFrame" data type. Default is "rooks". 
 #' @param verbose Whether to print initialization statement. Default is
 #' \code{TRUE}.
+#' @param adjobj Deprecated, use adj. An adjacency matrix, list, or object of class
+#' "SpatialPolygonsDataFrame."
+#' @param popvec Deprecated, use total_pop. A vector containing the populations of each geographic
+#' unit.
+#' @param initcds Deprecated, use init_plan. A vector containing the congressional district labels
+#' of each geographic unit. The default is \code{NULL}. If not provided, random
+#' and contiguous congressional district assignments will be generated using
+#' \code{redist.rsg}.
+#' @param popcons Deprecated, use pop_tol. The strength of the hard population
+#' constraint. \code{popcons} = 0.05 means that any proposed swap that
+#' brings a district more than 5\% away from population parity will be
+#' rejected. The default is \code{NULL}.
+#' @param grouppopvec Deprecated, use group_pop. A vector of populations for some sub-group of
+#' interest. The default is \code{NULL}.
+#' @param countymembership Deprecated, use counties. A vector of county membership assignments. The default is \code{NULL}.
+#' @param contiguitymap Use queens or rooks distance criteria for generating an
+#' adjacency list from a "SpatialPolygonsDataFrame" data type. Default is "rooks".
+#'
 #'
 #' @details This function allows users to simulate redistricting plans
 #' using Markov Chain Monte Carlo methods. Several constraints
-#' correspoding to substantive requirements in the redistricting process
+#' corresponding to substantive requirements in the redistricting process
 #' are implemented, including population parity and geographic
 #' compactness. In addition, the function includes multiple-swap and
 #' parallel tempering functionality in MPI to improve the mixing of the Markov
 #' Chain.
 #'
 #' @return \code{redist.mcmc.mpi} returns an object of class "redist". The object
-#' \code{redist} is a list that contains the folowing components (the
+#' \code{redist} is a list that contains the following components (the
 #' inclusion of some components is dependent on whether tempering
 #' techniques are used):
 #' \item{partitions}{Matrix of congressional district assignments generated by the
@@ -725,8 +729,8 @@ ecutsAppend <- function(algout,ndata){
 #' constraint for each accepted redistricting plan.}
 #' \item{constraint_compact}{A vector containing the value of the compactness
 #' constraint for each accepted redistricting plan.}
-#' \item{constraint_segregation}{A vector containing the value of the
-#' segregation constraint for each accepted redistricting plan.}
+#' \item{constraint_vra}{A vector containing the value of the
+#' vra constraint for each accepted redistricting plan.}
 #' \item{constraint_similar}{A vector containing the value of the similarity
 #' constraint for each accepted redistricting plan.}
 #' \item{beta_sequence}{A vector containing the value of beta for each iteration
@@ -743,79 +747,115 @@ ecutsAppend <- function(algout,ndata){
 #' Carlo." Working Paper. Available at
 #' \url{http://imai.princeton.edu/research/files/redist.pdf}.
 #'
+#' @concept simulate
 #' @examples
 #' \dontrun{
-#' data(algdat.pfull)
-#' ## Code to run the simulations in Figure 4 in Fifield, Higgins,
-#' ## Imai and Tarr (2015)
+#' data(fl25)
+#' data(fl25_enum)
+#' data(fl25_adj)
+#'
+#' ## Code to run the simulations in Figure 4 in Fifield, Higgins, Imai and
+#' ## Tarr (2015)
 #'
 #' ## Get an initial partition
-#' set.seed(1)
-#' initcds <- algdat.pfull$cdmat[,sample(1:ncol(algdat.pfull$cdmat), 1)]
+#' init_plan <- fl25_enum$plans[, 5118]
 #'
 #' ## Run the algorithm
-#' redist.mcmc.mpi(adjobj = algdat.pfull$adjlist,
-#' popvec = algdat.pfull$precinct.data$pop,
-#' initcds = initcds,
-#' nsims = 10000, savename = "test")
+#' redist.mcmc.mpi(adj = fl25_adj, total_pop = fl25$pop,
+#'                 init_plan = init_plan, nsims = 10000, savename = "test")
 #' }
 #' @export
-redist.mcmc.mpi <- function(adjobj, popvec, nsims, ndists = NA, initcds = NULL,
+redist.mcmc.mpi <- function(adj,
+                            total_pop,  nsims, ndists = NA,
+                            init_plan = NULL,
                             loopscompleted = 0, nloop = 1, nthin = 1,
                             eprob = 0.05,
-                            lambda = 0, popcons = NA, grouppopvec = NA,
+                            lambda = 0,
+                            pop_tol = NA,
+                            group_pop = NA,
                             areasvec = NA,
-                            countymembership = NA, borderlength_mat = NA,
+                            counties = NA,
+                            borderlength_mat = NA,
                             ssdmat = NA, compactness_metric = "fryer-holden", rngseed = NA,
                             constraint = NA, constraintweights = NA,
                             betaseq = "powerlaw",
                             betaseqlength = 10, adjswaps = TRUE,
                             freq = 100, savename = NA, maxiterrsg = 5000,
-                            contiguitymap = "rooks", verbose = FALSE
-){
+                             verbose = FALSE,
+                            adjobj, popvec, initcds, popcons, grouppopvec, countymembership, contiguitymap){
+
+  if(!missing(adjobj)){
+    .Deprecated(new = 'adj', old = 'adjobj')
+    adj <- adjobj
+  }
+  if(!missing(popvec)){
+    .Deprecated(new = 'total_pop', old = 'popvec')
+    total_pop <- popvec
+  }
+  if(!missing(initcds)){
+    .Deprecated(new = 'init_plan', old = 'initcds')
+    init_plan <- initcds
+  }
+  if(!missing(popcons)){
+    .Deprecated(new = 'pop_tol', old = 'popcons')
+    pop_tol <- popcons
+  }
+  if(!missing(grouppopvec)){
+    .Deprecated(new = 'group_pop', old = grouppopvec)
+    group_pop <- grouppopvec
+  }
+  if(!missing(countymembership)){
+    .Deprecated(new = 'counties', old = 'countymembership')
+    counties <- countymembership
+  }
+
+  if(!missing(contiguitymap)){
+    .Deprecated(msg = 'contiguitymap has been deprecated. Rooks adjacency built with redist.adjacency().')
+  }
+  contiguitymap <- 'rooks'
 
     ## Check if Rmpi library is installed
     if (!requireNamespace("Rmpi", quietly = TRUE)) {
         stop("You must install package 'Rmpi' to use this function. Please install it if you wish to continue."
             ,call. = FALSE)
     }
-    
+
     ## ## Load Rmpi library
-    ## if (!is.loaded("mpi_initialize")) { 
-    ##     library("Rmpi") 
+    ## if (!is.loaded("mpi_initialize")) {
+    ##     library("Rmpi")
     ## }
 
     ##########################
     ## Is anything missing? ##
     ##########################
-    if(missing(adjobj)){
+    if(missing(adj)){
         stop("Please supply adjacency matrix or list")
     }
-    if(missing(popvec)){
+    if(missing(total_pop)){
         stop("Please supply vector of geographic unit populations")
     }
     if(missing(nsims)){
         stop("Please supply number of simulations to run algorithm")
     }
-    if(is.na(ndists) & is.null(initcds)){
+    if(is.na(ndists) & is.null(init_plan)){
         stop("Please provide either the desired number of congressional districts
          or an initial set of congressional district assignments")
     }
     if(nloop > 1 & missing(savename)){
         stop("Please supply save directory if saving simulations at checkpoints")
     }
-    
+
     ###################
     ## Preprocessing ##
     ###################
 
-    ## Augment initcds if necessary
-    nrow.init <- ifelse(is.null(initcds), 0, nrow(initcds))
-    ncol.init <- ifelse(is.null(initcds), ndists, ncol(initcds))
+    ## Augment init_plan if necessary
+    nrow.init <- ifelse(is.null(init_plan), 0, nrow(init_plan))
+    ncol.init <- ifelse(is.null(init_plan), ndists, ncol(init_plan))
     if(nrow.init < betaseqlength){
-        initcds <- rbind(initcds,matrix(NA,betaseqlength-nrow.init,ncol.init))
+        init_plan <- rbind(init_plan,matrix(NA,betaseqlength-nrow.init,ncol.init))
     }
-    
+
     ## Generate temperature sequence (power law)
     temp <- rep(NA, betaseqlength)
     for(i in 1:betaseqlength){
@@ -823,7 +863,7 @@ redist.mcmc.mpi <- function(adjobj, popvec, nsims, ndists = NA, initcds = NULL,
     }
     beta <- temp/0.9
     target.beta <- beta[1]
-  
+
     ## Generate swapping sequence
     if(adjswaps){
         swaps <- matrix(NA,1,nsims*(nloop-loopscompleted))
@@ -843,10 +883,10 @@ redist.mcmc.mpi <- function(adjobj, popvec, nsims, ndists = NA, initcds = NULL,
             }
         }
     }
-    
+
     ## Create parameters list to distribute across nodes
     params <- expand.grid(nsims = nsims,nloop = nloop,eprob = eprob,
-                          ndists = ndists,lambda = lambda,popcons = popcons,
+                          ndists = ndists,lambda = lambda,pop_tol = pop_tol,
                           beta = beta,target.beta = target.beta,
                           constraint = paste(constraint, collapse = ","),
                           constraintweights = paste(constraintweights, collapse = ","),
@@ -856,69 +896,69 @@ redist.mcmc.mpi <- function(adjobj, popvec, nsims, ndists = NA, initcds = NULL,
                           contiguitymap = contiguitymap,verbose = verbose,
                           loopscompleted = loopscompleted,rngseed = rngseed,
                           savename = savename, stringsAsFactors = FALSE)
-    
+
     ##################
     ## Spawn Slaves ##
     ##################
     ## Note this will not work on Windows platform
     Rmpi::mpi.spawn.Rslaves(nslaves = betaseqlength)
-    
+
     ## Get processor ID for each slave
     Rmpi::mpi.bcast.cmd(procID <- Rmpi::mpi.comm.rank())
-    
+
     #########################
     ## Send Data to Slaves ##
     #########################
     ## Swapping Schedule
     Rmpi::mpi.bcast.Robj2slave(swaps)
-    
+
     ## Temperature adjacency
     if(adjswaps){
         Rmpi::mpi.bcast.Robj2slave(tempadj)
     }
-    
+
     ## Adjacency Object
-    Rmpi::mpi.bcast.Robj2slave(adjobj)
-    
+    Rmpi::mpi.bcast.Robj2slave(adj)
+
     ## Population Vector
-    Rmpi::mpi.bcast.Robj2slave(popvec)
-    
+    Rmpi::mpi.bcast.Robj2slave(total_pop)
+
     ## Initial Plans
-    initcds <- split(initcds, f=1:nrow(initcds))
-    Rmpi::mpi.scatter.Robj2slave(initcds)
-    
+    init_plan <- split(init_plan, f=1:nrow(init_plan))
+    Rmpi::mpi.scatter.Robj2slave(init_plan)
+
     ## Group population vector
-    Rmpi::mpi.bcast.Robj2slave(grouppopvec)
+    Rmpi::mpi.bcast.Robj2slave(group_pop)
 
     ## Areas vector
     Rmpi::mpi.bcast.Robj2slave(areasvec)
 
     ## County memberhsip vector
-    Rmpi::mpi.bcast.Robj2slave(countymembership)
+    Rmpi::mpi.bcast.Robj2slave(counties)
 
     ## Border distance matrix
     Rmpi::mpi.bcast.Robj2slave(borderlength_mat)
-    
+
     ## Squared-distance matrix
     Rmpi::mpi.bcast.Robj2slave(ssdmat)
-    
+
     ## Parameters List
     params <- split(params, f=1:nrow(params))
     Rmpi::mpi.scatter.Robj2slave(params)
-    
+
     ## Send ecutsMPI function to slaves
     Rmpi::mpi.bcast.Robj2slave(ecutsMPI)
-    
+
     ## Send ecutsAppend function to slaves
     Rmpi::mpi.bcast.Robj2slave(ecutsAppend)
-    
+
     ## Execute ecutsMPI program on each slave
-    Rmpi::mpi.bcast.cmd(ecutsMPI(procID, params, adjobj, popvec, initcds, swaps))
-    
+    Rmpi::mpi.bcast.cmd(ecutsMPI(procID, params, adj, total_pop, init_plan, swaps))
+
     ## Close slaves
     Rmpi::mpi.close.Rslaves()
-    
+
     ## Terminate MPI processes and close R
     Rmpi::mpi.quit()
-  
+
 }
