@@ -11,169 +11,199 @@
  * Main entry point.
  *
  * Sample `N` redistricting plans on map `g`, ensuring that the maximum
- * population deviation is within `tol`
+ * population deviation is between `lower` and `upper` (and ideally `target`)
  */
-IntegerMatrix smc_plans(int N, List l, const uvec &counties,
-                        const uvec &pop, int n_distr, double tol,
-                        double gamma, NumericVector &log_prob, double thresh,
-                        double alpha, int infl, int verbosity) {
+umat smc_plans(int N, List l, const uvec &counties, const uvec &pop,
+               int n_distr, double target, double lower, double upper, double rho,
+               double beta_sq, const uvec &current, int n_current,
+               double beta_vra, double tgt_min, double tgt_other,
+               double pow_vra, const uvec &min_pop,
+               double beta_vra_hinge, const vec &tgts_min,
+               double beta_inc, const uvec &incumbents,
+               vec &lp, double thresh,
+               double alpha, double pop_temper, int verbosity) {
+    // re-seed MT
+    generator.seed((int) Rcpp::sample(INT_MAX, 1)[0]);
+
     Graph g = list_to_graph(l);
     Multigraph cg = county_graph(g, counties);
     int V = g.size();
-    int N_max = infl * N;
-    umat districts(V, N_max, fill::zeros);
+    umat districts(V, N, fill::zeros);
     double total_pop = sum(pop);
-    double distr_pop = total_pop / n_distr;
+    double tol = std::max(target - lower, upper - target) / target;
 
     if (verbosity >= 1) {
+        Rcout << "SEQUENTIAL MONTE CARLO\n";
         Rcout << "Sampling " << N << " " << V << "-unit maps with " << n_distr
-              << " districts and population tolerance " << tol*100 << "%.\n";
+              << " districts and population between " << lower << " and " << upper << ".\n";
         if (cg.size() > 1)
             Rcout << "Ensuring no more than " << n_distr - 1 << " splits of the "
                   << cg.size() << " administrative units.\n";
     }
 
-    vec pop_left(N_max);
+    vec pop_left(N);
     pop_left.fill(total_pop);
-    vec lp(N_max, fill::zeros);
+    vec log_temper(N);
+    log_temper.fill(0.0);
+    lp.fill(0.0);
 
     int k;
-    int N_adapt = std::min((int) std::floor(4000.0 / sqrt((double)V)), N_max);
-    int N_sample = 0;
-    int valid = N_adapt;
-    double prob;
+    vec cum_wgt(N);
+    cum_wgt.fill(1.0 / N);
+    cum_wgt = cumsum(cum_wgt);
     for (int ctr = 1; ctr < n_distr; ctr++) {
         if (verbosity >= 1)
             Rcout << "Making split " << ctr << " of " << n_distr-1 << "\n";
 
         // find k and multipliers
-        adapt_parameters(g, k, prob, N_adapt, valid, lp, thresh, tol, districts,
-                         counties, cg, pop, pop_left, distr_pop);
-
-        int N_new = std::ceil(N / prob);
-        if (ctr == n_distr - 1) // safety margin for last step
-            N_new *= n_distr/2;
-        N_new = std::min(N_new, N_max);
+        adapt_parameters(g, k, lp, thresh, tol, districts, counties, cg, pop,
+                         pop_left, target, verbosity);
 
         if (verbosity >= 3)
-            Rprintf("Using k=%d for estimated success probability of %.2f%%\n",
-                   k, 100.0*prob);
+            Rcout << "Using k = " << k << "\n";
 
-        // Resample
-        resample_maps(N_sample, N_new, alpha, districts, lp, pop_left);
-        N_sample = N_new;
+        // perform resampling/drawing
+        split_maps(g, counties, cg, pop, districts, cum_wgt, lp, pop_left, log_temper,
+                   pop_temper, n_distr, ctr, lower, upper, target, rho, k, verbosity);
 
-        // perform sampling
-        split_maps(g, counties, cg, pop, districts, lp, pop_left, N_sample,
-                   n_distr, ctr, distr_pop, tol, gamma, k, verbosity);
-        valid = 0;
-        for (int i = 0; i < N_sample; i++) {
-            valid += std::isfinite(lp(i));
-        }
-
-        if (valid == 0) {
-            Rcout << "No valid samples at stage " << ctr << "; stopping sampling.\n"
-            << "Consider increasing `N` and/or `infl`.\n";
-            IntegerMatrix distr_ret(V, N);
-            return distr_ret;
-        }
-
-        if (verbosity >= 2)
-            Rprintf("%d valid samples (%.1f%% of total)\n", valid, (100.0*valid)/N_sample);
+        // compute weights for next step
+        cum_wgt = get_wgts(districts, n_distr, ctr, alpha, lp, pop,
+                           beta_sq, current, n_current,
+                           beta_vra, tgt_min, tgt_other, pow_vra, min_pop,
+                           beta_vra_hinge, tgts_min,
+                           beta_inc, incumbents, verbosity);
 
         Rcpp::checkUserInterrupt();
     }
 
-    resample_maps(N_sample, valid, alpha, districts, lp, pop_left);
+    lp = lp - log_temper;
 
-    // Output districts (and set final district label to n_distr rather than 0)
-    N = std::min(N, valid);
-    IntegerMatrix distr_ret(V, N);
-    int idx = 0;
+    // Set final district label to n_distr rather than 0
     for (int i = 0; i < N; i++) {
-        if (std::isinf(lp(i))) continue;
-        log_prob(idx) = lp(i);
         for (int j = 0; j < V; j++) {
-            distr_ret(j, idx) = districts(j, i) == 0 ? n_distr : districts(j, i);
+            districts(j, i) = districts(j, i) == 0 ? n_distr : districts(j, i);
         }
-        idx++;
     }
 
-    return distr_ret;
+    return districts;
 }
 
+
 /*
- * Resample partially-drawn maps according to their weights.
+ * Add specific constraint weights & return the cumulative weight vector
  */
-void resample_maps(int N_sample, int N_new, double alpha, umat &districts,
-                   vec &lp, vec &pop_left) {
-    if (N_sample == 0) return;
+vec get_wgts(const umat &districts, int n_distr, int distr_ctr,
+             double alpha, vec &lp, const uvec &pop,
+             double beta_sq, const uvec &current, int n_current,
+             double beta_vra, double tgt_min, double tgt_other,
+             double pow_vra, const uvec &min_pop,
+             double beta_vra_hinge, const vec &tgts_min,
+             double beta_inc, const uvec &incumbents, int verbosity) {
+    int V = districts.n_rows;
+    int N = districts.n_cols;
 
-    vec wgt = exp(-alpha * lp.subvec(0, N_sample - 1));
-    lp = lp * (1 - alpha);
+    for (int i = 0; i < N; i++) {
+        if (beta_sq != 0)
+            lp[i] += beta_sq * sq_entropy(districts.col(i), current, distr_ctr,
+                                          pop, n_distr, n_current, V);
+        if (beta_vra != 0)
+            lp[i] += beta_vra * eval_vra(districts.col(i), distr_ctr, tgt_min,
+                                         tgt_other, pow_vra, pop, min_pop);
+        if (beta_vra_hinge != 0)
+            lp[i] += beta_vra_hinge * eval_vra_hinge(districts.col(i), distr_ctr,
+                                                     tgts_min, pop, min_pop);
+        if (beta_inc != 0)
+            lp[i] += beta_inc * eval_inc(districts.col(i), distr_ctr, incumbents);
+    }
 
-    uvec idxs = as<uvec>(Rcpp::sample(N_sample, N_new, true, wrap(wgt), false));
+    vec wgt = exp(-alpha * lp);
+    if (distr_ctr < n_distr - 1) // not the last iteration
+        lp = lp * (1 - alpha);
+    vec cuml_wgt = cumsum(wgt);
 
-    lp = lp.elem(idxs);
-    pop_left = pop_left.elem(idxs);
-    districts = districts.cols(idxs);
+    if (verbosity >= 1) {
+        double neff = cuml_wgt[N-1] * cuml_wgt[N-1]  / sum(square(wgt));
+        Rprintf("Resampling effective sample size: %.1f (%.1f%% efficiency).\n", neff, 100*neff/N);
+    }
+
+    return cuml_wgt / cuml_wgt[N-1];
 }
 
 
 /*
- * Split off a piece from each map in `districts`, keeping deviation within `tol`
+ * Split off a piece from each map in `districts`,
+ * keeping deviation between `lower` and `upper`
  */
 void split_maps(const Graph &g, const uvec &counties, Multigraph &cg,
-                const uvec &pop, umat &districts, vec &lp, vec &pop_left,
-                int N, int n_distr, int dist_ctr, double distr_pop, double tol,
-                double gamma, int k, int verbosity) {
-    // absolute bounds for district populations
-    double upper = distr_pop * (1 + tol);
-    double lower = distr_pop * (1 - tol);
+                const uvec &pop, umat &districts, vec &cum_wgt, vec &lp,
+                vec &pop_left, vec &log_temper, double pop_temper, int n_distr,
+                int dist_ctr, double lower, double upper, double target,
+                double rho, int k, int verbosity) {
+    int V = districts.n_rows;
+    int N = districts.n_cols;
     int new_size = n_distr - dist_ctr;
     int n_cty = max(counties);
 
+    umat districts_new(V, N);
+    vec pop_left_new(N);
+    vec lp_new(N);
+    vec log_temper_new(N);
+
     int refresh = N / 10; // how often to print update statements
+    double iter = 0; // how many actual iterations
+    for (int i = 0; i < N; i++, iter++) {
+        // resample
+        int idx = rint(N, cum_wgt);
+        districts_new.col(i) = districts.col(idx);
+        double lower_s = std::max(lower, pop_left(idx) - new_size * upper);
+        double upper_s = std::min(upper, pop_left(idx) - new_size * lower);
 
-    for (int i = 0; i < N; i++) {
-        double lower_s = std::max(lower, pop_left(i) - new_size * upper);
-        double upper_s = std::min(upper, pop_left(i) - new_size * lower);
         // split
-        double inc_lp = split_map(g, counties, cg, districts.col(i), dist_ctr,
-                          pop, pop_left(i), lower_s, upper_s, distr_pop, k);
+        double inc_lp = split_map(g, counties, cg, districts_new.col(i), dist_ctr,
+                                  pop, pop_left(idx), lower_s, upper_s, target, k);
 
-        if (gamma != 1 && std::isfinite(inc_lp)) {
+        // bad sample; try again
+        if (!std::isfinite(inc_lp)) {
+            i--;
+            continue;
+        }
+
+        if (rho != 1) {
             double log_st = 0;
             for (int j = 1; j <= n_cty; j++) {
-                log_st += log_st_distr(g, districts, counties, i, dist_ctr, j);
+                log_st += log_st_distr(g, districts_new, counties, i, dist_ctr, j);
             }
-            log_st += log_st_contr(g, districts, counties, n_cty, i, dist_ctr);
+            log_st += log_st_contr(g, districts_new, counties, n_cty, i, dist_ctr);
 
             if (dist_ctr == n_distr - 1) {
                 for (int j = 1; j <= n_cty; j++) {
-                    log_st += log_st_distr(g, districts, counties, i, 0, j);
+                    log_st += log_st_distr(g, districts_new, counties, i, 0, j);
                 }
-                log_st += log_st_contr(g, districts, counties, n_cty, i, 0);
+                log_st += log_st_contr(g, districts_new, counties, n_cty, i, 0);
             }
 
-            inc_lp += (1 - gamma) * log_st;
+            inc_lp += (1 - rho) * log_st;
         }
-        lp(i) += inc_lp;
-
         // `lower_s` now contains the population of the newly-split district
-        pop_left(i) -= lower_s;
+        pop_left_new(i) = pop_left(idx) - lower_s;
+        double pop_pen = sqrt(n_distr - 2) * log(std::fabs(lower_s - target)/target);
+        log_temper_new(i) = log_temper(idx) - pop_temper*pop_pen;
+
+        lp_new(i) = lp(idx) + inc_lp - pop_temper*pop_pen;
 
         if (verbosity >= 2 && refresh > 0 && (i+1) % refresh == 0) {
             Rprintf("Iteration %'6d / %'d\n", i+1, N);
             Rcpp::checkUserInterrupt();
         }
     }
-
-    // ensure the leftover slots don't get sampled
-    int N_max = lp.size();
-    for (int i = N; i < N_max; i++) {
-        lp(i) = -log(0.0);
+    if (verbosity >= 2) {
+        Rprintf("%.1f%% acceptance rate.\n", 100.0 * N / iter);
     }
+
+    districts = districts_new;
+    pop_left = pop_left_new;
+    lp = lp_new;
+    log_temper = log_temper_new;
 }
 
 /*
@@ -222,8 +252,8 @@ double cut_districts(Tree &ust, int k, int root, subview_col<uword> &districts,
     for (int i = 0; i < V; i++) {
         if (districts(i) != distr_root || i == root) continue;
         double below = pop_below.at(i);
-        double dev1 = std::abs(below - target);
-        double dev2 = std::abs(total_pop - below - target);
+        double dev1 = std::fabs(below - target);
+        double dev2 = std::fabs(total_pop - below - target);
         if (dev1 < dev2) {
             candidates.push_back(i);
             deviances.push_back(dev1);
@@ -238,7 +268,7 @@ double cut_districts(Tree &ust, int k, int root, subview_col<uword> &districts,
 
     int idx = rint(k);
     idx = select_k(deviances, idx + 1);
-    int cut_at = std::abs(candidates[idx]);
+    int cut_at = std::fabs(candidates[idx]);
     // reject sample
     if (!is_ok[idx]) return 0.0;
 
@@ -266,16 +296,15 @@ double cut_districts(Tree &ust, int k, int root, subview_col<uword> &districts,
 /*
  * Choose k and multiplier for efficient, accurate sampling
  */
-void adapt_parameters(const Graph &g, int &k, double &prob, int N_adapt, int valid,
-                      const vec &lp, double thresh, double tol,
-                      const umat &districts, const uvec &counties,
+void adapt_parameters(const Graph &g, int &k, const vec &lp, double thresh,
+                      double tol, const umat &districts, const uvec &counties,
                       Multigraph &cg, const uvec &pop,
-                      const vec &pop_left, double target) {
+                      const vec &pop_left, double target, int verbosity) {
     // sample some spanning trees and compute deviances
     int V = g.size();
     int k_max = std::min(20 + ((int) std::sqrt(V)), V - 1); // heuristic
     int N_max = districts.n_cols;
-    N_adapt = std::min(N_adapt, valid);
+    int N_adapt = std::min((int) std::floor(4000.0 / sqrt(V)), N_max);
 
     std::vector<std::vector<double>> devs;
     vec distr_ok(k_max+1, fill::zeros);
@@ -306,6 +335,8 @@ void adapt_parameters(const Graph &g, int &k, double &prob, int N_adapt, int val
             distr_ok(n_ok) += 1.0 / N_adapt;
         if (n_ok > max_ok && n_ok < k_max)
             max_ok = n_ok;
+
+        Rcpp::checkUserInterrupt();
     }
 
     // For each k, compute pr(selected edge within top k),
@@ -326,15 +357,11 @@ void adapt_parameters(const Graph &g, int &k, double &prob, int N_adapt, int val
         if (sum_within / n_ok >= thresh) break;
     }
 
-    if (k == k_max + 1) {
-        Rcout << "Warning: maximum hit; falling back to naive k estimator.\n";
+    if (k >= k_max) {
+        if (verbosity >= 1) {
+            Rcout << "Note: maximum hit; falling back to naive k estimator.\n";
+        }
         k = max_ok + 1;
     }
-
-    prob = 0;
-    for (int i = 0; i <= k; i++) {
-        prob += ((double) i / k) * distr_ok(i);
-    }
-    if (prob == 0.0) prob = 1.0 / N_max; // happens sometimes
 }
 
